@@ -57,6 +57,20 @@ class TestCommodplot(unittest.TestCase):
         res = commodplot.forward_history_plot(cl)
         self.assertTrue(isinstance(res, go.Figure))
 
+    def test_candle_chart(self):
+        dirname, filename = os.path.split(os.path.abspath(__file__))
+        cl = pd.read_csv(os.path.join(dirname, 'test_cl_chlo.csv'), index_col=0, parse_dates=True, dayfirst=True)
+
+        res = commodplot.candle_chart(cl)
+        self.assertTrue(isinstance(res, go.Figure))
+
+    def test_stack_area_chart(self):
+        dirname, filename = os.path.split(os.path.abspath(__file__))
+        cl = pd.read_csv(os.path.join(dirname, 'test_cl_chlo.csv'), index_col=0, parse_dates=True, dayfirst=True)
+
+        res = commodplot.stacked_area_chart(cl)
+        self.assertTrue(isinstance(res, go.Figure))
+
     def test_reindex_year_line_subplot(self):
         dr = pd.date_range(start='2015', end='2020-12-31', freq='B')
         data = {'Q1 2019': [10 for x in dr], 2020: [20 for x in dr], 2021: [30 for x in dr], 2022: [10 for x in dr]}
