@@ -11,7 +11,7 @@ class TestCommodPlotTrace(unittest.TestCase):
     def test_min_max_range(self):
         df = cf.datagen.lines(1, 5000)
         dft = transforms.seasonailse(df)
-        res = cptr.min_max_range(dft, shaded_range=5)
+        res = cptr.min_max_mean_range(dft, shaded_range=5)
         self.assertTrue(isinstance(res[0], pd.DataFrame))
         self.assertTrue(isinstance(res[1], int))
 
